package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`\P`!````>AX```````!``````````*"A````
M````!0```$``.``*`$``%@`5``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```!P`@``````
M`'`"````````<`(````````:`````````!H``````````0`````````#``!P
M!````(&@`````````````````````````````%,````````````````````!
M``````````$````%````````````````````````````````````A),`````
M``"$DP`````````0`````````0````8```"XFP```````+BK````````N*L`
M``````"8!````````/`$`````````!`````````"````!@```,B;````````
MR*L```````#(JP```````.`!````````X`$````````(``````````0````$
M````C`(```````",`@```````(P"````````)``````````D``````````0`
M````````4.5T9`0```#HBP```````.B+````````Z(L```````#T````````
M`/0`````````!`````````!1Y71D!@``````````````````````````````
M```````````````````````````0`````````%+E=&0$````N)L```````"X
MJP```````+BK````````2`0```````!(!`````````$`````````+VQI8B]L
M9"UM=7-L+7)I<V-V-C0N<V\N,0````0````4`````P```$=.50"2#VZ?G>.R
MEJ^G<JV`<>^@LZ(BAA$```!,````!`````@````@D!``!4`$@"@`$02`A@2$
M@H$``@D`!`B(@!!!N@`"B`````!,````3P```%(```!3````6@```%L```!<
M````7@```%\```!@````8@```&,```!D````9@``````````````SMY'+6[%
MWQ]K?YI\+L6;MB#_Y`[59-1\V7%8'+(!BV^83\.;PN4_+$+ZUX?ZH6Q@NN.2
M?.-'Q@%5PSS29Z_,9H@'<--#1=7L<U"?V#-BV^T^S])L%8PES/]A\F%_J9R;
MX*<""FL:GE"CX/M)``````````````````````````````````````,`"0#P
M'```````````````````D`(``!(`````````````````````````NP$``!(`
M````````````````````````8````!(`````````````````````````W`(`
M`!(`````````````````````````P0```!$`````````````````````````
MCP$``!(`````````````````````````1````!(`````````````````````
M````.0$``!(`````````````````````````^`$``!(`````````````````
M````````N````!(`````````````````````````TP```"(`````````````
M````````````6`$``!(`````````````````````````W0$``!(`````````
M````````````````?@(``!(`````````````````````````H`$``!(`````
M````````````````````'`$``!(`````````````````````````EP(``!(`
M````````````````````````YP(``"$`````````````````````````/@``
M`!(`````````````````````````Y@(``!$`````````````````````````
MT`$``!$`````````````````````````1P$``!(`````````````````````
M````2@0``"(`````````````````````````9P(``!(`````````````````
M````````<````!(`````````````````````````%P(``!(`````````````
M````````````Z`(``!$`````````````````````````J0```!(`````````
M````````````````/@(``!(`````````````````````````)@```"``````
M````````````````````;0$``!(`````````````````````````_0```"``
M````````````````````````Y0(``"$`````````````````````````>```
M`!(`````````````````````````%P$``!(`````````````````````````
M:````!(`````````````````````````60```!(`````````````````````
M````%P```!(`````````````````````````-0(``!(`````````````````
M````````K@(``!(`````````````````````````"0```!(`````````````
M````````````KP$``!(`````````````````````````AP```"``````````
M````````````````IP(``!(`````````````````````````5P(``!(`````
M````````````````````4@```!(`````````````````````````!`(``!(`
M`````````````````````````0```!(`````````````````````````2P``
M`!(`````````````````````````/@0``!(`````````````````````````
MQ`(``"(`````````````````````````20(``!(`````````````````````
M````GP(``!(`````````````````````````$````!$`````````````````
M````````)0(``!(`````````````````````````>0```!(`````````````
M````````````A0(``!(`````````````````````````'P```!(`````````
M````````````````(@$``!(`````````````````````````^````!(`````
M````````````````````?`$``!8`````````````````````````M0(``!(`
M````````````````````````R@(``!(`````````````````````````0`$`
M`!(`````````````````````````HP```!(`````````````````````````
ML0```!(`````````````````````````?@```!(`````````````````````
M````7P$``!(`````````````````````````<@(``!(`````````````````
M````````,P$``!(`````````````````````````X@```"``````````````
M````````````[@$``!(`````````````````````````J````!(`````````
M````````````````\P$``!(`````````````````````````JP,``!(`"0"<
M+0```````+X$````````N`,``!(`"0`X-````````*0`````````UP(``!(`
M"0#P'````````(H!````````+P,``!(`"0"X)`````````(`````````9`,`
M`!(`"0"Z)````````-H!````````>0,``!(`"0!:,@```````-X!````````
MT`,``!``$@!0L```````````````````2@,``!(`"0`4*P```````$X`````
M````<0,``!(`"0!B*P```````$(`````````CP,``!(`"0"&(P```````"@`
M````````H`,``!(`"0":1P```````#H!````````W`,``!(`"0#@+```````
M`+P`````````&@0``!``$@"HL```````````````````'P0``!(`"0"4)@``
M`````"(`````````EP,``!(`"0"2'@```````"(`````````6`,``!(`"0"V
M)@````````8!````````0`,``!$`$0!(L`````````@`````````$P0``!``
M$0!0L```````````````````'P,``!``$0!0L```````````````````U0,`
M`!(`"0!Z'@``````````````````!`0``!``$0``L```````````````````
M1P0``!(`"0!&1P```````%0`````````Q`,``!``$@"HL```````````````
M````+`0``!(`"0#(+````````!@`````````[@,``!(`"0"N(P````````H!
M````````4`0``!(`"0#42````````+(!````````$@,``!(`"0"\)P``````
M`%@#`````````&]P96YD:7(`;65M8VUP`'-T9&5R<@!R96%L;&]C`&%C8V5S
M<P!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L<V5E:P!G971P:60`<W1R8VUP
M`&UE;7-E=`!U;FQI;FL`;65M;6]V90!S=')N8VUP`'-T<G)C:'(`;'-T870`
M8VQO<V5D:7(`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`&]P96X`=F9P
M<FEN=&8`<W1R8VAR`')E861L:6YK`%]?<W1A8VM?8VAK7V=U87)D`%]?8WAA
M7V9I;F%L:7IE`%]?<F5G:7-T97)?9G)A;65?:6YF;P!E>&ET`%])5$U?<F5G
M:7-T97)434-L;VYE5&%B;&4`<F5A9`!R;61I<@!?7V5R<FYO7VQO8V%T:6]N
M`&UK9&ER`&UE;6-P>0!S=')L96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`
M4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!03%]C=7)R96YT7V-O;G1E
M>'0`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S
M=@!097)L7V-R;V%K7VYO8V]N=&5X=`!03%]D;U]U;F1U;7``4&5R;%]N97=8
M4U]F;&%G<P!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL
M;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E
M<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P
M87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!S=')C<'D`<F5A
M9&1I<@!S<')I;G1F`'-T<F1U<`!S=')T;VL`<'1H<F5A9%]A=&9O<FL`7V9I
M;FD`7U]L:6)C7W-T87)T7VUA:6X`<VYP<FEN=&8`7U]?96YV:7)O;@!L:6)P
M97)L+G-O`&QI8F,N;75S;"UR:7-C=C8T+G-O+C$`<&%R7VEN:71?96YV`%]?
M4T1!5$%?0D5'24Y?7P!P87)?8W5R<F5N=%]E>&5C`&UY7W!A<E]P;`!P87)?
M96YV7V-L96%N`'!A<E]D:7)N86UE`'!A<E]F:6YD<')O9P!P87)?9&EE`%A3
M7TEN=&5R;F%L<U]005)?0D]/5`!X<U]I;FET`%]S=&%R=%]C`'-H85]U<&1A
M=&4`<&%R7VUK=&UP9&ER`'!A<E]C;&5A;G5P`%]?0E-37T5.1%]?`%]?8G-S
M7W-T87)T`'!A<E]S971U<%]L:6)P871H`'!A<E]C=7)R96YT7V5X96-?<')O
M8P!?7T1!5$%?0D5'24Y?7P!?961A=&$`7V5N9`!P87)?8F%S96YA;64`9V5T
M7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<VAA7VEN:70`<VAA7V9I;F%L`"]U
M<W(O;&EB+W!E<FPU+V-O<F5?<&5R;"]#3U)%`+BK`````````P````````!0
M'P```````,"K`````````P`````````"'P```````-"O`````````P``````
M``#P'`````````"P`````````P``````````L````````!BP`````````P``
M``````#02P```````""P`````````P`````````X3@```````"BP````````
M`P````````!`3@```````#"P`````````P````````!(3@```````#BP````
M`````P````````!03@```````$BP`````````P````````!83@```````("O
M`````````@````8``````````````(BO`````````@````<`````````````
M`)"O`````````@````P``````````````)BO`````````@```!8`````````
M`````*"O`````````@```!@``````````````*BO`````````@```!P`````
M`````````+"O`````````@```!\``````````````+BO`````````@```"$`
M`````````````,"O`````````@```"P``````````````,BO`````````@``
M`"X``````````````-BO`````````@```#```````````````."O````````
M`@```#0``````````````.BO`````````@```#<``````````````/"O````
M````"P```#X``````````````/BO`````````@```$@``````````````+BM
M````````!0````(``````````````,"M````````!0````,`````````````
M`,BM````````!0````0``````````````-"M````````!0````4`````````
M`````-BM````````!0````@``````````````."M````````!0````D`````
M`````````.BM````````!0````H``````````````/"M````````!0````L`
M`````````````/BM````````!0````T```````````````"N````````!0``
M``X```````````````BN````````!0````\``````````````!"N````````
M!0```!```````````````!BN````````!0```!$``````````````""N````
M````!0```!(``````````````"BN````````!0```!0``````````````#"N
M````````!0```!<``````````````#BN````````!0```!D`````````````
M`$"N````````!0```!H``````````````$BN````````!0```!L`````````
M`````%"N````````!0```!T``````````````%BN````````!0```!X`````
M`````````&"N````````!0```"```````````````&BN````````!0```",`
M`````````````'"N````````!0```"0``````````````'BN````````!0``
M`"4``````````````("N````````!0```"8``````````````(BN````````
M!0```"<``````````````)"N````````!0```"@``````````````)BN````
M````!0```"D``````````````*"N````````!0```"H``````````````*BN
M````````!0```"L``````````````+"N````````!0```"T`````````````
M`+BN````````!0```"\``````````````,"N````````!0```#$`````````
M`````,BN````````!0```#(``````````````-"N````````!0```#,`````
M`````````-BN````````!0```#4``````````````."N````````!0```#8`
M`````````````.BN````````!0```#@``````````````/"N````````!0``
M`#D``````````````/BN````````!0```#H```````````````"O````````
M!0```#L```````````````BO````````!0```#P``````````````!"O````
M````!0```#T``````````````!BO````````!0```#\``````````````""O
M````````!0```$```````````````"BO````````!0```$$`````````````
M`#"O````````!0```$(``````````````#BO````````!0```$,`````````
M`````$"O````````!0```$0``````````````$BO````````!0```$4`````
M`````````%"O````````!0```$8``````````````%BO````````!0```$<`
M`````````````&"O````````!0```$D``````````````&BO````````!0``
M`$H``````````````'"O````````!0```$L`````````````````````````
MEY,``#,#PT$#OH-%$P-#_9."@T434Q,`@[*"`&<`#@`7G@```SZ.1&<##@`3
M````%YX```,^#D1G`PX`$P```!>>```#/HY#9P,.`!,````7G@```SX.0V<#
M#@`3````%YX```,^CD)G`PX`$P```!>>```#/@Y"9P,.`!,````7G@```SZ.
M06<##@`3````%YX```,^#D%G`PX`$P```!>>```#/HY`9P,.`!,````7G@``
M`SX.0&<##@`3````%YX```,^CC]G`PX`$P```!>>```#/@X_9P,.`!,````7
MG@```SZ./F<##@`3````%YX```,^#CYG`PX`$P```!>>```#/HX]9P,.`!,`
M```7G@```SX./6<##@`3````%YX```,^CCQG`PX`$P```!>>```#/@X\9P,.
M`!,````7G@```SZ..V<##@`3````%YX```,^#CMG`PX`$P```!>>```#/HXZ
M9P,.`!,````7G@```SX..F<##@`3````%YX```,^CCEG`PX`$P```!>>```#
M/@XY9P,.`!,````7G@```SZ..&<##@`3````%YX```,^#CAG`PX`$P```!>>
M```#/HXW9P,.`!,````7G@```SX.-V<##@`3````%YX```,^CC9G`PX`$P``
M`!>>```#/@XV9P,.`!,````7G@```SZ.-6<##@`3````%YX```,^#C5G`PX`
M$P```!>>```#/HXT9P,.`!,````7G@```SX.-&<##@`3````%YX```,^CC-G
M`PX`$P```!>>```#/@XS9P,.`!,````7G@```SZ.,F<##@`3````%YX```,^
M#C)G`PX`$P```!>>```#/HXQ9P,.`!,````7G@```SX.,6<##@`3````%YX`
M``,^CC!G`PX`$P```!>>```#/@XP9P,.`!,````7G@```SZ.+V<##@`3````
M%YX```,^#B]G`PX`$P```!>>```#/HXN9P,.`!,````7G@```SX.+F<##@`3
M````%YX```,^CBUG`PX`$P```!>>```#/@XM9P,.`!,````7G@```SZ.+&<#
M#@`3````%YX```,^#BQG`PX`$P```!>>```#/HXK9P,.`!,````7G@```SX.
M*V<##@`3````%YX```,^CBIG`PX`$P```!>>```#/@XJ9P,.`!,````7G@``
M`SZ.*6<##@`3````%YX```,^#BEG`PX`$P```!UQANRFY*J'HNC*X$[\EY0`
M`(.T)"@NZ#+D#`@P`&@(/LZ<8#[T@4?O\)_:%Y8```,VQBNRA1>5```#-24F
M[_`_\)>7``"#MV<F@\<'`/'/EY<``(.W!RL7E```$P0$-)*7F&-R28-'ITL;
M!4D`#@63YS<`(PWW2N_PG_/"9?)'".2880TIJH88X1<W```3!^<*&.47EP``
M`S='+!CI%S<``!,')PH8[05'8UGW#!N(-P!"AJ$%$4>(89,7-P"VEP4GB..A
M!>,9!_^;!P8`C@<(;+:7`4=*AI<%``"3A456([`'`._PW\D]Q0ALDPE!`N_P
M']TJB<Z%%S4``!,%A=?O`(`8*<T(;._PG^SO\%_I(G><8+F/`4>]Y^9@1F2F
M9.)Y2H4&:25A@H#O\'_=%Y0``!,$I"8(["'%[_!_OY>7``"#MR<<A68SAT<`
M&&,VER,+!Y8QMPAL[_"?S7FW"&@!Q>\08%Y%M\Z%%S4``!,%Y<CO`&`1".A9
MU>6WD4>!OP5%[_#_VN_PO[Z7H0``DX%AF`J%EY4``).%1=03<0'_":`,01,&
MA0"!1Q>7```#-V<4EY8``(.VY@\7E0```S5E$GFS%Y4``!,%Q1F7EP``DX='
M&6.(IP"7EP``@[>'#Y'#@H>"@!>5```3!:47EY4``).%)1>)C9/7-4#]D;Z5
MA869Q9>7``"#MT<,D<."AX*`01$BX!>4```3!*04@T<$``;DE>N7EP``@[>G
M!Y''%Y4```,U!0Z"E^_PO_B7EP``@[<G")''%W4``!,%A=J"EX5'(P#T`*)@
M`F1!`8*`EY<``(.WAPJ9ST$1!N27E0``DX6E#Q=U```3!:77@I>B8$$!C;>%
MMSEQ!OPB^%G%6N"7EP``@[=G`@.[!P!C`0L(2O!.[%+H@T<%`*J)+HHJB1,'
MT`.ERV.&YP"#1QD`!0G]^SL).4$#-`L`.<PF]%;DVH23"M`#2H;.A2*%[_`_
MLK,')`$)Y8/'!P!C@%<#@&2A!'7PHG0">>)I0FJB:@)KXG`BA4)T(6&"@+.$
M9$&-A`4)(R":`$J4\;\!1-6W`FL!1/F_`4E%MP)YXFE":@)KP;]Q<2+Q)NT&
M]9>4``"#M$3U+`"<8#[E@4<JA._P/ZD-X>)'O6819_6/8X7G`"EG8YKG`(E%
M(H7O\'^Z$S45`!&@`44J9YQ@N8\!1Y'GJG`*=.ID36&"@._P?YXQ<4[M!OV7
MF0``@[G)[X.W"0`^Y8%'&<4B^8-'!0`JA('O2G0J9X.W"0"YCP%'^>/J<.II
M*6&"@";U2O'O\'^LJH1!R2:%[_#?ES7-@T<U`1,)-0&;AR?]@>>#1QD`_=.#
M1S4!FX<G_:W+(H52Z>_P7[8JBDJ%[_#?M3L%J@`))>_P/Y'*AB*&ES4``).%
M)9@JB>_P'ZLL`$J%[_"?K/U78PCU`.)'O6819_6/8X#G!$J%[_`?G4J%[_"_
MNB:%2FKO\#^00?4FA>_PO[,BA>_P7XY*=*IT"GFQMX-'&0";AR?]P?>#1RD`
ML=]!MTJ%[_`_\=&W(ODF]4KQ4NGO\'^.'7&BZ*;DRN!2^(;L3OQ6]%KP@\<%
M`!>9```#.<G>JH23AS?\D[<7`#.$]0`BA8,W"0`^Y(%'[_#?J2J*3``FA>_P
MO]MYR:J)[_"_J&-V10N22A>;```#.XO=C@H#QP0`IH>3!M`#8P@'$F,&UP`#
MQQ<`A0=]^X6?@SD+`!,%*@`^E=:9[_#_@".PJ0`QQ0,W"P"#QP0`$X44`%:7
M%&,3!M`#(X#V`('KO:"#1P4`!06C`/<`K<,VAX4&XYC'_I,&T`.3!Q<`(P#7
M``-'!`"%!P4$HX_G_G7[(F>#-PD`N8\!1]WOYF!&9*9D!FGB>4)ZHGH">R5A
M@H"#1P0`A0D%!*./^?[QVX-'!`"%"04$HX_Y_OWST;<VAUVW7NQBZ!>;```#
M.\O0`SP+`(,W#`"UQ^*'@4F89\Z&H0>%*67_C2:3E38`EY<``).'9]R80Q7K
M!4<NA9C#[_#/\ZJ+,<63FCD`5H;BA>_PS^HC,'L!FX<9`(X'OILCL`L`XFM"
M;$["\;UBA>_P_X`C,*L`JHL)S9.:.0#IOX%'Q;7!18%)7;=>[&+H[_#O\^)K
M0FPUMT$1(N`7E````S0$S`;DEW8``).&YHBS!T0`B&,7E@```S8&R)<E``"3
MA05T[_"/]1*4"&`"9*)@%S<``!,'QZN!1[J&%Q8``!,&INZ7)0``DX6%<T$!
M;_#OYY>7``"#MZ?&EW8``).&IH,7E@```S8FPY*7B&.7)0``DX7E;F_P;_`Y
M<2+X^7()9`;\2O`F]!,'A`$6D0J7%YD```,YR;N#-PD`'..!1^_PS]WY=Z$7
M$P<$`CZ7,P0G`(5EJH87)P``$P?G;1<F```3!N9MA04BA>_P+]K]5V,&]0J%
M9&/BI`K]=8EGP163AP<"KI>SA"<`(H4%9J:%[_#/VQL$!0!C0@0(&P44`._P
MS]VJASW)8W:5`#,'A0!CY>0&?7>)9D$7DX8&`KJ6,X<F`&-H]P0%9P4'8V>'
M!/UU"6?!%1,'!P(NER*&/H6S!2<`[_"/U"J4JH<C``0`"6=A!PJ7%&,#-PD`
M-8^!1@7CB6(6D>)P0G2B=`)Y/H4A88*`(I?C^>?Z`I"!1\F_[_#/VMV]A6;]
M=U%Q_7*3AT?W$X<&":+QINW*Z6+QAO7.Y=+A5OU:^5[U9NUJZ3Z7%I$NA+,%
M)P`3AX8("I<7G````SSLJ"J)@S<,`!SC@4<7)0``$P5%7N_PWZ:JA),%\`)*
MA>_PC_4AQ1<E```3!:5=RH7O\'_%2H6%9Y.'APB*EYAC@S<,`+F/`4=CF`<4
MA6(6D:YP#G3N9$YIKFD.:NIZ2GNJ>PI\ZFQ*;6UA@H`BA>_PK]^7)0``DX7E
M6>_P[]LJA%W1A6?]>>$9$X<'"4Z7LPDG`!.'!PF3AP<)BI<%:OUZLXQ'08-'
M!`"3BHKW5I>7*P``DXNK5A<K```3"ZM6LPHG`-G#D<2BA2:%[_#OW"7!(H7O
M\&_H$P?U_R*7*HV3!O`"8VCD`#&H(P`'`'T78P;D`(-'!P#CB=?^(H7O\,_E
M*HU*A>_P3^5JE04%XWU%\<J'7H>BAEJ&A65.A>_PS[@%)6-_J@("D(/'%`"%
MYY<E``"3A25.`47O\`_0*H3C!`7N@T<$`+W_D<2#QP0`FX<G_?G;!4T7)```
M$P0D256WUH5.A>_P3]AY\8.GC/B]9B%G]8_CG>?ZA45.A>_PS]A=]<Z%%R4`
M`!,%Q4?O\+^O3H7O\&_-1;7O\`^]01&3!?`"(N`&Y"J$[_`/OAG!$P05`"*%
M`F2B8$$!;_#ORGEQA6?]<DKH!O0B\";L$X>'`!:1%YD```,Y:8L*EX,W"0`<
MXX%'7<&#1P4`JH39S^_PK]8%!85G8^.G#'UT813!!Z*7,X0G`*:%(H7O\.^F
M(H7O\(_4DP?U_Z*7DP;P`B*%8VCT`!&H(X`'`/T78X:G``/'!P#C"=?^?76%
M9V$5P0>JES.$)P"3!?`"(H7O\,^S#<UC8J0&?76%9V$5P0>JES.%)P#O\$_`
MA6>A!XJ7F&.#-PD`N8\!1Z'GA6(6D:)P`G3B9$)I16&"@(5GH0>*EYAC@S<)
M`+F/`4>=XX5B%I&B<`)TXF1":1<E```3!04T16%O\&^[(P`%`'&_`45MM^_P
MCZHY<2+X)O1*\$[L!OR7A```@[2$>YQ@/N2!1T``%RD``!,)B327B0``@[F)
M?**%2H7O\,_X%<$21X.W"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_"O]F7Q
M%RD``!,)R3&7B0``@[G)>**%2H7O\`_U%<$21X.W"0`.![J7F&>8XV77F&NA
M!YCC;?^BA4J%[_#O\F7Q%RD``!,)B2Z7B0``@[D)=:*%2H7O\$_Q%<$21X.W
M"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_`O[V7Q%RD``!,)R2N7B0``@[E)
M<:*%2H7O\(_M%<$21X.W"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_!OZV7Q
M%RD``!,)B2B7B0``@[F);:*%2H7O\,_I%<$21X.W"0`.![J7F&>8XV77F&NA
M!YCC;?^BA4J%[_"OYV7Q%RD``!,)R267B0``@[G)::*%2H7O\`_F%<$21X.W
M"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_#OXV7Q%RD``!,)B1J7B0``@[D)
M9J*%2H7O\$_B%<$21X.W"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_`OX&7Q
M%RD``!,)21^7B0``@[E)8J*%2H7O\(_>%<$21X.W"0`.![J7F&>8XV77F&NA
M!YCC;?^BA4J%[_!OW&7Q%RD``!,)B1R7B0``@[F)7J*%2H7O\,_:%<$21X.W
M"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_"OV&7Q%RD``!,)R1F7B0``@[G)
M6J*%2H7O\`_7%<$21X.W"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_#OU&7Q
M%RD``!,)B0R7B0``@[D)5Z*%2H7O\$_3%<$21X.W"0`.![J7F&>8XV77F&NA
M!YCC;?^BA4J%[_`OT67QHH47)0``$P4E$^_P+]"JA1G%%R4``!,%)1#O\(_O
MHH47)0``$P7%$N_P3\ZJA1G%%R4``!,%11/O\*_MHH47)0``$P5E$^_P;\RJ
MA07-%R4``!,%Y0+O\,_K(F><8+F/`4>IXT)TXG"B=`)YXFF7)0``DX7E$A<E
M```3!>4&(6%O\"_IHH47)0``$P7E#^_P[\>JA7G1%R4``!,%Y0;O\$_G9;_O
MX!_U`1$BZ`;L%X0```,T9$9,`!<E```3!<4$'&`^Y(%'[_!OQ!7!@T<%``%%
MB<>3AP?],S7P`")G'&"YCP%'F>?B8$)D!6&"@`%%];?OX#_P*HX7A0```S5%
M2!UQ"&$3`X$"+O0R^+[D!NPV_+K@PNC&[)>'``"#M\<_&H;RA9AC.N0!1QK@
M[_"/DQ,%\`_O\`^(67&B\,%R063.Y-+@9NR&]*;LRNA6_%KX7O1B\!,'A``6
MD0J7EXP``(.\C#N#MPP`'..!1PE&@44JBN_@/^>3"?7_$]?Y0T&3LX?I`,(7
MP9.9C[.)^4!CQPD*P73!%),'!`'!:Z:7_5JSA"<`H0L=3!>)```3"4D_07L!
M1LZ%4H7OX-_B8PA5"5Z&IH52A>_@_^H!)6,*50=C<ZP&814SA*0`8W:4`*&H
M?11C:I0$(4;*A2*%[^"?[F7YP7=!9\$700<^E[,')P`S!?1`3I7!9Z$'BI>8
M8X.W#`"YCP%'J>/!8A:1IG`&=.9D1FFF:09JXGI">Z)[`GSB;&5A@H#:F>.=
M:?=]5>&W%R4``!,%1??O\/_J%R4``!,%A?7O\#_J[^#?V4$1!N3OX%_2`27O
MX/_L$<$(8:)@00&"@#EQ)O1*\`;\%XD```,YB2FJA$P`%R4``!,%Q?.#-PD`
M/N2!1^_P3Z<9Q2+X@T<%`"J$G>-"=")G@S<)`+F/`4>FA1<E```3!>7PO>/B
M<*)T`GDA86_PK\0FA4[L[^!?\:J)(H7OX-_P3I4)!>_@7\PBAY<F``"3AF;;
M)H:7)0``DX7%VRJ$[^"_Y2)G@S<)`+F/`4>5XZ*%0G3B:>)PHG0">1<E```3
M!>7J(6%O\"^_(OA.[._@W\SOX)_,EX<``).'QR8)<8.X!P$#N(<!D'.4=YA[
MG'_*\L[NTNJ&_J+Z%XH```,Z"AP#,PH`&O8!0Q<C```3`X/G$PG!`+[TER<`
M`).')^>JB1KH/O07(P``$P-#SY<G``"3AT?FRH47)0``$P6ESAKL`O#&X,+D
MLNBV[+KP/O@"_._P#Y81Q8-'!0`JA&.<!QRF]M;F[^!?O`$E[^#_UF,'!10`
M86,$!!0BA>_@_^`&!04%[^!_O`-&!`"JA*J*!<+:XA<K```3"^O@)H7:A>_@
MO]4#1A0`B00%!&7Z%FN$`!<E```3!875(:"(9*$$#<'*A>_P[XXJA&W9@T<%
M`/77[_#/F'W1(H7OX!_,*H01[00(@&`9R(-'!`#YQR*%[_#OED7M@&2A!'WT
M(H7OX-_8JH16A>_@7]BIG)N$1$`FA>_@G[/6AQ<G```3!R?9ER8``).&IL(B
MAI<E``"3A878JHKOX'_,DP4`'%:%[^#?VOU78QCU`._@/]`80<5'8Q3W#(P8
M5H7OX#^[*H09Y8I'O6819_6/8X[G")>'``"#MV<+`[8)`(ACUH:7)0``DX5E
MV._@?[6!1#)W@S<*`+F/`4=CE`<N]G!6=+9J%GGV:59J)H6V=!EA@H`BA>_@
MW[XJA*$$'=61MP%$@;<B=200&<G*A>_@W_X!Q8-'!0"-XXADH01]]35%VN+O
MX/^FJH2JBA<D```3!&3)$P8P!56U[^"?NBJ$:=WOX!_)!@4%!4FUVN(J2^_@
M/Z*;!P4`8P7[!!9KF;^7AP``@[>G``.V"0"(8]:&ER4``).%I<GOX+^JD;_O
M\%_.,G>#-PH`N8\!1V.1!R0BA59T]G`6>?9I5FH986_@7[2*1U[^8OH3!P`<
MD_?W'V.&YP`6:_)[4GSMO2:%[^!?G<J%JH07)0``$P7%S>_@W_*JA6,+!1`#
MM0D`[_`/QJJ+8P0%$%Z%[^"_OAL+!0"-1V/89P,3!<O_ER4``).%!<M>E>_@
M_[`)[9%'8P#[&)L'N__>EP/'!P"3!_`"8P?W%LJ%%R4``!,%Y:SOX/_L8<&#
M1P4`S<\3!P`#8XKG"I<E``"3A:6T%R4``!,%I:KO\`^+[^#_C2J'ER<``).'
MA]27)@``DX8&HU:&ER4``).%Y<8FA>_@WZQ]6<5)%RP``!,,3-*7*P``DXO+
MH!<K```3"\O%%:#OX+^O'$%CE3<#[^`?B04D*H=BB**'WH96AMJ%)H7OX-^H
MDP4`'":%[^`_M^,*)?U6A>_@G[FFA1<E```3!:69[_"/@B:%[_!?N!9K\GM2
M?.VS@[L)`.6]@45>A>_@_ZXJB3G1[_"_HJJ)XT\%\I,%9?\!1DJ%[^!?C!,+
M`0\91MJ%2H7OX'^4F4=C&_4(3E>W1T%#DX<',.,8]_`#5TL`D6>3AX=4XQ'W
M\`%&DX7I_$J%[^"?B*`9$P:``J*%2H7OX+^0DP>``F,<]027)P``DX?GPR*'
MER8``).&1I)6AI<E``"3A26U)H4C``$2[^#?FSV_@[F)`..)">A.A>_@WZ.-
M1^/SI^AQ%9<E``"3A06Q3I7OX'^6XQD%YLZ+M;47)0``$P4EL._P7Y+:XE[^
M8OKOX)^!IO;6YMKB7OYB^N_@OX!=<:+@%X0```,T)-E*^$[TAN0F_%+PLP=$
M`(1CDPE!`!>)```#.6G0@\<$"\Z%%R4``!,%A8P#-PD`.N0!1Z.(]`KOX-_-
M&<4#1P4`DP<0`V,+]Q+O\._0LP=$`(1C)H6-1@5&ER4``).%):SOX+^0JH0=
MP1QI,P=$``ACC&,7)@``$P8&J^_@#_N<:(QCW$43EY<"8T`'$K,'1`"(8XU&
M!4:7)0``DX5%J>_@WXRJA!>*```3"NK7#<'.A1<5```3!25^[^"_Q2J&><&<
M:#,'1``(8XQC[^`/]K,'1`"$8P5&ER4``).%Q:4FA>_@OX"JA1<F```3!D:F
M)H7OX*_S$I0<8,Z%%Q4``!,%A7BCB`<*[^#?P",XJ@`AR9,%`!SOX'^3&P<5
M`(5'8_+G`L5'8P_U`%;L@S>*``,V"@&JAHQC%R4``!,%1:3OX,_=(F>#-PD`
MN8\!1\'CIF`&9.)T0GFB>0)Z86&"@`,UB@#O\%^=(SBJ`%WQ%R4``!,%99Y6
M[._@3]J#1Q4`XXH'[-FU5NSOX#_\JHH%Q9QH,P=$``ACC&-6AN_@#^E6A>_@
MOXWB:B6WLP=$`(AC[^#/V^F]@S:*`)AHLP=$`)!B#&.(8^_@;^;B:A&W5NSO
MX,_B>7$B\";L!O07A````S0$M*J$3``7%0``$P5%<AQ@/N2!1^_@_[$!S8-'
M!0")RQ,'``-CAN<`@<2#QP0`F>LB9QQ@N8\!1Z'OHG`"=.)D16&"@":%2NCO
M\(^BDP7P`BJ)[^"/WAG!$PD5`$J%[^#/ZQ%&EQ4``).%97SOX._C&<%":76_
M(F<<8+F/`4>1ZP)T0FFB<":%XF1%86_@W[I*Z._@C]@3`0'4(SB!*B,\$2HC
M-)$J(S`A*R,\,2DC.$$I%X0```,TA*@T`,%N?5\<8",T\2B!1Y,(A0.3`H4'
M-H@37P\"MP__`)..#O`#M@@`00BA")-5!@(3%X8!DQ.&`)-7A@(37H8`DU2&
M`Q.3A0$S=^<!L_/S`;/WUP$S9W<`,W[>`<6/,W/C`:(%,V?'`1M6A@&SYV<`
ML_7U`5&/S8\C..C^(SSX_N.2$OO]5<9_9G\*9^)N`GXB<\)X8GB&8Y.$!B"!
MD1&@LH.P8IQBNH*A!K&/L\?W`;/'UP$3EQ<`_8-=CVV/N/[ZC_*.%H\:CD:#
MPH@>B..9EOR#/@4`HF\#.`4!`S.%`(,XA0$#/@4"-X>"6A,'EYF3U[X!$Y9>
M`%V.NI\37R,`DQ?C`6V.\I^S1A@!L^?G`;/V9@!^EL)O,_^W`+/&%@$VEK-&
MZ`%MCK/VU@&ZGY,25@"35+8!QI^SQ@8!_I:S[Y(`$]DN`).3[@'^EN)OL^,C
M`;/'=P#QC[J?[8ZSQ^<!PI^3E%8`$]FV`9,2Y@'^EPF"@G^SXL(`,^8D`;*7
M,\93`+J?L_.S`'6.[8]^GS-&=@"3E%<`$]FW`9.?Y@%ZEHF"(G^S[]\`L^8D
M`3:6L\;R`6V.L_*R`/V..I\>GY,45@`36;8!L\96`).3YP&)@[/C\P#ZEK/G
M)`&^EC/_M@#"=K/'?P#QC[/_OP"ZEI:6DQ1?`!-9OP&SQ_<!MI>SYB0!MI>3
M$N8!"8*SXL(`,_:W`.)WL\93`+/VY@&S\[,`NI?^EY,45@`36;8!L\9V`+Z6
ML^<D`;Z6DQ_O`1-?+P"S[^\!,_^V`(9FL\?R`?&/L_*R`+J6GI:3%%\`$UF_
M`;/'5P"VE[/F)`&VEY,3Y@$)@K/CPP`S]K<`IF>SQG\`L_;F`;/_OP"ZEY:7
MDQ16`!-9M@&SQO8!OI:SYR0!OI:3$N\!$U\O`+/BX@$S_[8`QF:SQU,`\8^S
M\[,`NI;^EI,47P`36;\!L\=W`+:7L^8D`;:7DQ_F`0F"L^_/`#/VMP#F9[/&
M\@&S]N8!L_*R`+J7GI>3%%8`$UFV`;/&5@"^EK/G)`&^EI,3[P$37R\`L^/C
M`3/_M@"&=K/'?P#QC[/_OP"ZEI:6DQ1?`!-9OP&SQ_<!MI>SYB0!MI>3$N8!
M"8*SXL(`,_:W`*9WL\93`+/VY@&S\[,`NI?^EY,45@`36;8!L\9V`+Z6L^<D
M`;Z6DQ_O`1-?+P"S[^\!,_^V`,9VL\?R`?&/L_*R`+J6GI:3%%\`$UF_`;/'
M5P"VE[/F)`&VEY,3Y@$)@K/CPP`S]K<`YG>SQG\`L_;F`;/_OP"ZEY:7DQ16
M`!-9M@&SQO8!OI:SYR0!OI:3$N\!$U\O`+/BX@$S_[8`BF:SQU,`\8^S\[,`
MNI;^EI,47P`36;\!L\=W`+:7L^8D`;:7DQ_F`0F"L^_/`#/VMP"J9[/&\@&S
M]N8!L_*R`+J7GI>35+8!DQ-6`+/&5@`3&>\!OI837R\`L^>3`,IC,V_I`;Z6
ML\?O`>V.L_^_`+J3\8^>DI/4M@&SQ_<!DY-6`+/CDP"6E^IDDQ+F`0F"L^+"
M`)Z7[8\S1E\`NI0S?[\`$]FW`76.DY-7`*:?,T;F`;/C(P&S\[,`?I:3G^8!
MB8(>EK/OWP`*>;-TM@"SQO(!_8ZS\K(`DY-4`)/9M`$ZF3/'5@"SYC,!DY/G
M`8F#L^/S`$J?L\=_`.V.>I>QCRIV,P_7`#?WV6X3!Q>ZLWF_`!/9N0$ZEI.6
M60`6ENV/L^8F`;*7[8Z^EI.2Y`'*=XF`L^*2`#/YM@`SQE,`L_^_`)-4N0&Z
MES-/Y@$3%ED`,W^_`/Z718[ZEVV./I:3G^D!ZG>3V2D`L^\_`;-TM@`SS_(!
ML_.S`)/9M`&ZES-/WP"3EE0`,W^_`)Z7L^8V`?J7[8Z^EA,?Z0&.9Q-9*0`S
M;R\!L_.V`#/)[P&S^;(`NI>S0LD`$]FS`1.64P"S\K(`SI<S9B8!EI=MCCZ6
MDY+D`:YGB8"SXI(`,TE?`+-TM@"S^;\`NI>S3]D`$]FT`9.65`"S_[\`SI>S
MYB8!_I?MCKZ6DY_C`<YGD],C`+/O?P`SR?(!L_.V`+-YOP"ZES-/R0`3V;,!
M$Y93`#-_OP#.ES-F)@'ZEVV./I83G^0![F>)@#-OGP`SR>\!LW2V`+/YL@"Z
ME[-"V0`3V;0!DY94`+/RL@#.E[/F)@&6E^V.OI:3DN,!CG>3TR,`L^)R`#-)
M7P"S\[8`L_F_`+J7LT_)`!/9LP$3EE,`L_^_`,Z7,V8F`?Z7;8X^EI.?Y`&N
M=XF`L^^?`#/)\@&S=+8`LWF_`+J7,T_9`!/9M`&3EE0`,W^_`,Z7L^8F`?J7
M[8Z^EA.?XP'.=Y/3(P`S;W\`,\GO`;/SM@"S^;(`NI>S0LD`$]FS`1.64P"S
M\K(`SI<S9B8!EI=MCCZ6DY+D`>YWB8"SXI(`,TE?`+-TM@"S^;\`NI>S3]D`
M$]FT`9.65`"S_[\`SI>SYB8!_I?MCKZ6DY_C`9)GD],C`+/O?P`SR?(!L_.V
M`+-YOP"ZES-/R0`3V;,!$Y93`#-_OP#.ES-F)@'ZEVV./I83G^0!LF>)@#-O
MGP`SR>\!LW2V`+/YL@"ZE[-"V0`3V;0!DY94`+/RL@#.E[/F)@&6E^V.OI:3
MDN,!TF>3TR,`L^)R`#-)7P"S\[8`L_F_`+J7LT_)`!/9LP$3EE,`L_^_`,Z7
M,V8F`?Z7;8X^EI.?Y`'R9XF`L^^?`#/)\@&S=+8`LWF_`+J7,T_9`!/9M`&3
MEE0`,W^_`,Z7L^8F`?J7[8Z^EA.?XP&2=Y/3(P`S;W\`,\GO`;/SM@"S^;(`
MNI>S0LD`$]FS`1.64P"S\K(`SI<S9B8!EI=MCCZ6DY+D`;)WB8"SXI(`,TE?
M`+-TM@"S^;\`NI>S3]D`$]FT`9.65`"S_[\`SI>SYB8!_I?MCKZ6DY_C`=)W
MD],C`+/O?P`S^;8`L\/R`;-YOP"ZES//PP"34[D!$Q99`#-_OP#.ES-F=@!M
MCOJ7,X_'`).3Y`'R=XF`L^.3`#/&?P"S=+\`L_*R`+J7L8[MCI/9M`&6EY.2
M5`"VE[/F,@&VEQ,6Z0&69A-9*0`S9B8!,\G#`+/RMP"S_[\`LT?I`;J6D]FR
M`?Z6$YE2`+/_MP`S:3D!_I;*EA.?Y`&)@#-OGP`W]\8CLW2V`/U7]8VV9H&3
M"@<3!\?-LW__`#-FY@$S^?0!NI8S=E8`L_/S`+:3D]FU`3-F)@$3F54`'I:S
M8SD!'I:S<_8`DY;B`59FD](B`+/F5@"S\O8`,V_?`#/Y7P`ZEC-_OP"RE)/9
MLP$S;R\!$YE3`":?LV0Y`1.6Y0$FGXF!]F1-CK-U]@#1CC-__P`S^;(`L_9V
M`+J4_I236;\!L^8F`1,97P"FEK-D.0$3FN,!D]\C`*:6EG2S;_H!L_/_`#-F
M]@']CC/Y=0"ZE#-VY@&FDC-F)@&3E%8`$]FV`;/D)`$6EI,9[P$FEA-?+P"V
M=#/OZ0&S<O\`L^_O`7V.,_E3`+/_WP"ZE+/O+P&NE!,95@"36;8!DY7F`8F"
MU8VSAI\`LV\Y`?Z6UG^S]/4`,V^_`/V.,_F2`+J?,W_/`#-O+P'^DQ.95@"3
MV;8!DQ_F`0F"L^_/`#,&?P`S;SD!>I9V?[/S_P"SY?4!?8XS^70`.I_UC;/E
M)0'ZDA,95@"36;8!$Y_F`8F",V_?`+.&50"S93D!KI::9;-R_P"S[^\!_8XS
M^5,`NI6S_\\`L^\O`:Z4$YE6`)/9M@&3%>8!"8+1C3.&GP"S;SD!?I:Z;[/T
M]0`S;[\`?8XS^9(`NI\S?]\`,V\O`?Z3$QE6`)-9M@&3G^8!B8*S[]\`LP9_
M`#-O.0'ZEEIOL_/_`+/E]0']CC/Y=``ZG_&-L^4E`?J2$YE6`)/9M@$3'^8!
M"8(S;\\`,X95`+-E.0$NEOIELW+_`+/O[P%]CC/Y4P"ZE;/_WP"S[R\!KI03
M&58`DUFV`9.5Y@&)@M6-LX:?`+-O.0'^EII_L_3U`#-OOP#]CC/YD@"ZGS-_
MSP`S;R\!_I,3F58`D]FV`9,?Y@$)@K/OSP`S!G\`,V\Y`7J6.G^S\_\`L^7U
M`7V.,_ET`#J?]8VSY24!^I(3&58`DUFV`1.?Y@&)@C-OWP"SAE4`LV4Y`:Z6
MVG6S<O\`L^_O`?V.,_E3`+J5L__/`+/O+P&NE!.95@"3V;8!DQ7F`0F"T8TS
MAI\`LV0Y`2:6^G2S__4`,V^_`'V.,_GR`3-_WP"ZE#-O+P&>E!,95@"36;8!
MDY/F`8F"L^/3`+,&GP"S9#D!'FDS__,`L^5U`*:6\8VS].\!.IG]CA:9Q8V3
MF58`$]JV`9-2)@"3%.8!RI4^:;/D5``SYDD!L_+T`+*5,^:3`'6.L_/U`#J9
MLW5?`'Z9DYE3`!/:LP%-CI/?)@"3E>8!2I:SYDD!L^7U`3:6L^:T`+-T]@!>
M9K/_]0`S^?(!L_9V`#J6>I:SYB8!$Y]4`!/9M`$S;R\!LI9^:1.6XP&3TR,`
M,V9V`+-S]@#ZEM&-_8XS^G\`Y8TZF1.?5@"3V;8!%IFSY44!LV(_`<J5$]\D
M`!.9Y`&S9.D!'G^S\O(`EI5%CK/R]``S^?4`,_I3`'6..I^36;D!$Q=9`'Z?
M,V9&`;-O-P%ZEI.9Y@$3WR8`,^_I`;/&Y`&S__\`K8XWMY@ROG6RGPH'$P=G
M';/Y_P"3U+D!NI43EED`GI7]CD6.DQ/I`1-9*0"SXR,!?8ZNEK.%Q@`S1G\`
M,T;V`=Y_L_3U`!/9M`&ZGY.65`"6GWV.L^8F`?V.?I8VEI.?Z0'^=I/9*0"S
M[S\!,WGV`+/"\P&S>?\`NI8SS[(`DU*Y`9,560`S?_\`SI:SY54`^I;]C;:5
M$Y_D`8,V`2")@#-OGP"SPN\!L_3U`+/S\P"3V;0!NI:SPL(`$Y94`+/R\@">
MEC-F-@&6EGV.-I:3$ND!@S:!(!-9*0"SXB(!LW/V`#-)7P"S^?\`NI:S3[D`
M$]FS`9.54P"S__\`SI:SY24!_I;]C;:5DY_D`8,V`2&)@+/OGP`SR?(!L_3U
M`+-Y_P"ZEC-/R0`3V;0!$Y94`#-__P#.EC-F)@'ZEGV.-I83G^,!@S:!(9/3
M(P`S;W\`,\GO`;-S]@"S^?(`NI:S0KD`$]FS`9.54P"S\O(`SI:SY24!EI;]
MC;:5DY+D`8,V`2*)@+/BD@`S25\`L_3U`+/Y_P"ZEK-/R0`3V;0!$Y94`+/_
M_P#.EC-F)@'^EGV.-I:3G^,!@S:!(I/3(P"S[W\`,\GR`;-S]@"S>?\`NI8S
M3[D`$]FS`9.54P`S?_\`SI:SY24!^I;]C;:5$Y_D`8,V`2.)@#-OGP`SR>\!
ML_3U`+/Y\@"ZEK-"R0`3V;0!$Y94`+/R\@#.EC-F)@&6EGV.-I:3DN,!@S:!
M(Y/3(P"SXG(`,TE?`+-S]@"S^?\`NI:S3[D`$]FS`9.54P"S__\`SI:SY24!
M_I;]C;:5DY_D`8,V`22)@+/OGP`SR?(!L_3U`+-Y_P"ZEC-/R0`3V;0!$Y94
M`#-__P#.EC-F)@'ZEGV.-I83G^,!@S:!))/3(P`S;W\`,\GO`;-S]@"S^?(`
MNI:S0KD`$]FS`9.54P"S\O(`SI:SY24!EI;]C;:5DY+D`8,V`26)@+/BD@`S
M25\`L_3U`+/Y_P"ZEK-/R0`3V;0!$Y94`+/__P#.EC-F)@'^EGV.-I:3G^,!
M@S:!)9/3(P"S[W\`,\GR`;-S]@"S>?\`NI8S3[D`$]FS`9.54P`S?_\`SI:S
MY24!^I;]C;:5$Y_D`8,V`2:)@#-OGP`S^?4`L\3O`;/Y\@"ZEK/"Q`"35+D!
M$Q99`+/R\@#.ED6.EI9]CC:6DY3C`8,V@2:3TR,`L^1T`+-"GP"S<_8`L_G_
M`+J6L\^R`)/2LP&3E5,`L___`,Z6L^55`/V-_I:SC[8`DQ+I`8,V`2<362D`
ML^(B`;/%5``S^?\`,W__`)-9N0&ZEK&-$Q99`/V-^I8S9C8!?8ZNEK.%Q@`3
MG^,!`S:!)Y/3(P`S;W\`L\;B`;/S]0#]C#J6L\;V`?V.)I:3V;,!DY13`#:6
ML^8T`3:6@S8!*),?Z0$362D`L^\O`;J6LT3_`3-W]@#VEK/R\@`SQK0`?8Z3
M%5<`DUZW`9:6LI8SYM4!DY7C`9/3(P"REK/E=0#]CCJ3,P;/`3.'!0&SA1\!
M?8\4X?V-LW;S`/&/&.D<\13E#.T#-X$H'&"YCP%'A>.#,($K`S0!*X,T@2H#
M.0$J@SF!*0,Z`2D3`0$L@H#OT.^Q01$3!0`(!N3OT"^LMW9=3#=WZ6&W)45G
MDX45,(8&-U8R$`8'#.&3AN;/ET4``(.U!4<3!F9'$P<''PSE%.D0[1CQ(S0%
M`B,X!0(C+`4&HF!!`8*`77$F_$KX4O!6[(;DHN!.]!AUDQ<V`!1YNI>"%X&3
M,[?G`"J*NI8H71-7U@$VER,T^@(C..H"LH2NBA,)B@,QQ1,$``2[!Z1`/H1C
M2O8,$PF*`TJ58WQ5#;,'A0"SB8H`8^SZ"B*&UH7OT.^;@R>*!Q,'``2[AH<`
M(RS:!F.;Y@92A8&<[^#_R\Z*DP?P`V/3EP1:Z%[D5H23B0H$DPN*!Q,+\`-C
M<(D&8V-T!\Z*HH43!@`$2H7OT`^74H6;A`3\[^`_R!,$!`23B0D$XTR;_$)K
MHFMC;ED#8_8J`;.'F@!C;/D")H;6A4J%[]#/DR,LF@:F8`9DXG1">:)Y`GKB
M:F%A@H#.BN-T)/OC<CG[`I"S!YD`X_CZ_%KH7N0"D!,)B@-*E1L$!@#C:%7S
MLXF*`./ZJO+C>#7SQ;=Y<2+P)NQ2X`;T2NA.Y(.YA0(3BH4#DP8`^!/6.0`3
M=O8#,P?*``.Y!0.3!Q8`(P#7`!,'@`,NA*J$!29C5_<2$P<`!!&?D48S!?H`
M8W77%(E'8WGW$F,4!Q(BA>_@W[H3!H`#@452A>_03Z.35@D!$U>)`)/V]@^B
M!IM7B0$3=_</0@?5CQ-Y^0]B"=F/&]:)`9/6"0$"%K/G)P$3UXD`D_;V#Z(6
MT8\3=_</0A?5C^(9V8^SYS<!//@BA>_@W[0<8"*%X8,C@/0`'&#!@Z.`]``<
M8*&#(X'T`!Q@HX'T`!QDX8,C@O0`'&3!@Z."]``<9*&#(X/T`!QDHX/T`!QH
MX8,CA/0`'&C!@Z.$]``<:*&#(X7T`!QHHX7T`!QLX8,CAO0`'&S!@Z.&]``<
M;*&#(X?T`!QLHX?T`!QPX8,CB/0`''#!@Z.(]``<<*&#(XGT`!QPHXGT``)T
MHG#B9$)IHFD":D5A;]!OJA,'@`,[!L=`@44S!?H`[]!/DL6](P`%`.&](P`%
M`*,`!0!Y%PD%XP4'[.VW(P`%`*,`!0`C`04`HP$%`'$7B4<1!>-E]^K1OP``
M)7,O)7,```!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(``````$EN=&5R
M;F%L<SHZ4$%2.CI"3T]4`````&5X90``````+W!R;V,O)6DO)7,``````"X`
M````````4$%27U1%35```````````%!!4E]04D]'3D%-10`````Z````````
M`"\`````````)7,E<R5S``!015),-4Q)0@``````````4$523$Q)0@!015),
M-4]05```````````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.
M140``````%!!4E]#3$5!3@````````!005)?1$5"54<`````````4$%27T-!
M0TA%`````````%!!4E]'3$]"04Q?1$5"54<``````````%!!4E]'3$]"04Q?
M5$U01$E2`````````%!!4E]435!$25(```````!005)?1TQ/0D%,7U1%35``
M4$%27T=,3T)!3%]#3$5!3@``````````,0````````!L<V5E:R!F86EL960`
M````<F5A9"!F86EL960``````$Q$7TQ)0E)!4EE?4$%42`!365-414T``"]T
M;7``````55-%4@````!54T523D%-10``````````)3`R>`````!P87(M````
M`"5S)7,E<R5S```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D
M:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R:79A
M=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I
M="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%!!5$@`````<&%R
M;``````N<&%R`````'-H;W)T(')E860````````E<R5S8V%C:&4M)7,E<P``
M)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,``````````!@`````
M````<&5R;``````P`````````%!!4CHZ4&%C:V5R.CI615)324].`````#$N
M,#8S````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````````
M`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@*&5R<FYO/25I*0H``````````"UE````````+2T```````!4
M35!$25(``%1%35!$25(`5$5-4`````!435```````&5V86P@)V5X96,@+W5S
M<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN
M:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"10
M05)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE
M*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O
M9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ
M92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I
M;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@
M/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D
M<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@
M("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*
M=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D
M9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII
M9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2![
M"G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR
M971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL
M92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@
M>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64[
M"G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N
M86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL
M97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U
M8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M
M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU3
M5VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@
M/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE
M*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*
M;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB
M+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D
M<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A
M:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N
M86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM
M>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E
M;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T
M;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B![
M"DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS
M.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE
M="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@
M(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@
M("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G
M(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_
M("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P
M<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T
M<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY
M("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z
M('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E
M;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E
M860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H
M97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@
M)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC
M7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B
M)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#
M.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?
M<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I
M>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE
M;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U
M9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD
M(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B
M(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T
M7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*
M;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@
M9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D
M;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD
M<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E
M7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@
M("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q
M(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S
M*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@
M/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@
M=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN
M*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@
M86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE
M;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*
M?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D
M8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U
M:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]
M"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?
M.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O
M(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O
M.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE
M?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%
M04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M
M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O
M+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E
M('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L
M("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P
M96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T
M(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O
M;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE
M(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ
M2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z
M.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I
M<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES
M("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65]
M(&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^
M("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O
M("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE
M7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*
M?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@
M9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=
M*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T
M.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G
M<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID
M96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@
M;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R
M("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY
M("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?
M<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y
M7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@
M>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!
M4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D
M7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-
M3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*
M<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE
M=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`
M<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R
M.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE
M;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H
M)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@
M>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@
M;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A
M8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@
M)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI
M=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M
M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@
M9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN
M8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER
M92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A
M<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@
M>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@
M9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I
M;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D
M<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@
M)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]
M?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A
M(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D
M<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#
M86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D
M("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL
M95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*
M0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O
M=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@
M?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG
M="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E
M96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?
M;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?
M;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD
M;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD
M("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY
M*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@
M<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D
M8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H
M*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD
M;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL
M:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI
M.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E
M9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E
M9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG
M.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D
M;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y
M<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY
M("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@
M)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI
M*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H
M)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E
M9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E
M9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D
M;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U
M;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK
M*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB
M7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N
M+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@
M)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M
M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T
M:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE
M(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL
M=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D
M;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<
M+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^
M;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP
M<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P
M<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D
M8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI
M+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@
M1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M
M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE
M*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@
M=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[
M8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@
M*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(
M02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I
M.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E
M<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C
M86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE
M7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H
M)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^
M=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@
M)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%
M<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W
M-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R
M=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0[
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN
M97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII
M<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N
M;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*
M07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]
M($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE
M*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R
M(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B
M73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S
M:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N
M86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T
M:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S
M("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R
M7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E
M<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R
M8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D
M,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM0
M05)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F
M)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S
M*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@
M97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X
M=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D[
M"B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C
M=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L
M("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S
M("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL
M97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@
M6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@
M+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R
M96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S
M96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A
M<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&
M:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M
M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U
M:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R
M.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A
M<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#
M87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I
M<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A3
M3&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR
M97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER
M92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0[
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ
M1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A
M;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V
M86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!
M<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(
M87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R
M97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@
M?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T
M96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D
M14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!4
M35`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@
M9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D
M=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I
M9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,
M;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*
M?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED
M.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6
M>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y
M<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER
M("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?
M0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P
M96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T
M(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@
M9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC
M7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL
M(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B
M*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?
M<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM
M("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?
M;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C
M:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2![
M"B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$[
M"GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I
M<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*
M;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@
M)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY
M("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE
M(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2![
M"FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N
M("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT
M96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@
M(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D
M969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R
M('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B
M(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-
M17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N
M86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%
M35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P
M*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O
M9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!2
M3T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@
M,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R
M;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@
M>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C
M:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0
M051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I
M<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]
M7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA
M;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U]
M)'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D
M96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]
M("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H
M)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B
M+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D
M("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97
M:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO
M;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L
M:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@
M/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[
M4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*
M)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$
M(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E
M("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.
M($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,
M7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H
M)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]
M"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP
M<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*
M?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G
M<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C
M:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N
M9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E
M<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2
M+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E
M;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I
M<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64[
M"D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI
M+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]
M"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<
M*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*
M7U]%3D1?7PH`<&5R;'AS:2YC``````````!#04-(10``B:O-[P`````!&P,[
M]````!T````(D?__=`8``,R2__\,`0``[I+__R`!```:D___-`$``&B3__]8
M`0``D)/__W@!```\E/__Y`$``):4__\0`@``EI7__V@"``!$E___R`(``)Z7
M___L`@``QI?__P`#``#0F/__-`,``-*8__](`P``K)K__YP#``#.FO__O`,`
M`-2;__\`!```+)___S0$``!ZG___6`0``+R?__]P!```X*#__\`$``#XH/__
MW`0``+2A__\P!0``<J;__]P%``!0J/__+`8``/2H__^H!@``7KO__^`&``"R
MN___``<``.R\__]@!P```````!```````````WI2``%\`0$;#0(`$````!@`
M``"XD?__(@`````````0````+````,:1__\L`````````"````!`````WI'_
M_TX`````0@X00H@$3H$"=L%"R$(.`````!P```!D````")+__R@`````3`X0
M0H$"5,%"#@``````:````(0````0DO__K`````!"#D!$@0*(!$R6$%*2"),*
ME`QFB0:5#F;)0M)"TT+40M5"UD+!1,A"#@!"#D"!`H@$B0:2"),*E`R5#I80
M4,G2T]35UD26$$+61)((DPJ4#)801M)"TT+40M8`*````/````!0DO__6@``
M``!"#K`!1H@$B0:!`@)&"L%"R$+)0@X`0@L```!4````'`$``'Z2__\``0``
M`$(.P`%$DPJ!`EB(!$;(3L%"TT(.`$(.P`&!`H@$DPI$B0:2"'*4#`)2U%0*
MR$+)0M)""U*4#$C(R=+42(@$B0:2")0,````7````'0!```FD___K@$```!"
M#F!4B`2)!I((E`R!`I,*E0Z6$`+0"L%"R$+)0M)"TT+40M5"UD(.`$(+;I<2
MF!0"5@K70MA$"U37V$27$I@41M?81)<2F!1&UT+8````(````-0!``!TE/__
M6@````!"#A!"B`1*@0)HR$+!7@X`````$````/@!``"JE/__*``````````P
M````#`(``+Z4__\*`0```$(.0$2(!$X.P$"!`I((B08"V`H.0$+!0LA"R4+2
M1`X`0@L`$````$`"``"4E?__`@````````!0````5`(``(*5___:`0```$8.
M\`%F#O`AB`2)!I((F!2!`I,*E`R5#I80EQ*9%IH8`F(*#O`!0L%"R$+)0M)"
MTT+40M5"UD+70MA"V4+:0@X`0@L<````J`(```B7__\B`````$(.$$B(!($"
M4,A"P4(.`$````#(`@``"I?__P8!````0@XP4@ZP()((@0*(!(D&`JP*#C!"
MP4+(0LE"TD(.`$(+5@H.,$+!0LA"R4+22@X`1`L`,`````P#``#,E___6`,`
M``!"#D!*B`2)!I((DPJ!`@,*`PK(0L%"R4+20M-2#@!$"P```"````!``P``
M\)K__TX`````0@X@1(@$@0)Z"L%"R$(.`$(+`!0```!D`P``&IO__T(`````
M3`Y@3H$2`$P```!\`P``1)O__R0!````0@YP1(@$7`[P@`23"I0,F1:!`HD&
MD@B5#I80EQ*8%`+""@YP0L%"R$+)0M)"TT+40M5"UD+70MA"V4(.`$(+&```
M`,P#```8G/__&`````!"#A!"@0)0P4(.`%````#H`P``%)S__[P`````0@Y`
M1HD&D@B!`FB(!$;(6,%"R4+20@X`1`Y`@0*(!(D&D@A$DPH"/LA"TT+!0LE"
MTDH.`$0.0($"B0:2"$2(!),*`*@````\!```?)S__[X$````2@Z``UJ2"),*
ME`R!`H@$`FR)!I4.;I807-8#Z@`*P4+(0M5"TD+30M1$R4(.`$(+<`J6$%8+
M5)804-9@R=56R$+!0M)"TT+40@X`1`Z``X$"B`2)!I((DPJ4#)4.EA!.EQ*8
M%$;60M="V$*6$)<2F!0#*`$*UD+70MA""P/:`-;7V$:6$)<2F!1$R=76U]A*
MB0:5#I80EQ*8%`!,````Z`0``(Z@___>`0```$(.4$*(!%:2"),*@0*)!I0,
M`S`!"I4.1`M."L%"R$+)0M)"TT+40@X`0@M8"I4.1`M,E0Y@U4Z5#E;51)4.
M`$0````X!0``'*+__Z0`````0@XP1H@$B0:!`@)""L%"R$+)0@X`0@M$D@AL
M"M)""TS(0M)"P43)0@X`1`XP@0*(!(D&0I((`#````"`!0``C(K__XH!````
M0@Y@3($"B0:(!)((DPH##@$*P4+(0LE"TT320@X`0@L````T````M`4``$2B
M__]J$@```$0.P`58B`2!`HD&D@B3"I0,`S`2"L%$R$3)1-)$TT341`X`0@L`
M`!P```#L!0``=K3__U0`````0@X01H$"`DC!0@X`````7`````P&``"JM/__
M.@$```!"#E!@B0:2")0,E0Z!`H@$DPH">I80EQ)VUD+78,%"R$+)0M)"TT+4
M0M5"#@!"#E"!`H@$B0:2"),*E`R5#I80EQ),UM=,EA"7$D+6UP``-````&P&
M``"$M?__L@$```!"#C!,B`2)!I0,@0*2"),*`TP!"LA"P4+)0M)"TT+40@X`
M1`L`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````$`````````\`(````````!`````````/L"````````'0``
M``````!:!`````````P````````````````````-````````````````````
M&0````````"XJP```````!L`````````"``````````:`````````,"K````
M````'``````````(`````````/7^_V\`````L`(````````%`````````#@-
M````````!@````````"0`P````````H`````````>`0````````+````````
M`!@`````````%0````````````````````,`````````J*T````````"````
M`````$`%````````%``````````'`````````!<`````````"!0````````'
M`````````+`1````````"`````````"8!P````````D`````````&```````
M```>``````````@`````````^___;P`````!```(`````/G__V\`````"@``
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````/______
M____``````````!0&0```````%`9````````4!D```````!0&0```````%`9
M````````4!D```````!0&0```````%`9````````4!D```````!0&0``````
M`%`9````````4!D```````!0&0```````%`9````````4!D```````!0&0``
M`````%`9````````4!D```````!0&0```````%`9````````4!D```````!0
M&0```````%`9````````4!D```````!0&0```````%`9````````4!D`````
M``!0&0```````%`9````````4!D```````!0&0```````%`9````````4!D`
M``````!0&0```````%`9````````4!D```````!0&0```````%`9````````
M4!D```````!0&0```````%`9````````4!D```````!0&0```````%`9````
M````4!D```````!0&0```````%`9````````4!D```````!0&0```````%`9
M````````4!D```````!0&0```````%`9````````4!D```````!0&0``````
M`%`9````````R*L`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````"E!!4BYP;0H`````````````````````````
M````````````````````````````````````````````````````````````
M1T-#.B`H06QP:6YE(#$S+C(N,5]G:70R,#(T,#,P.2D@,3,N,BXQ(#(P,C0P
M,S`Y`$%2````<FES8W8``4@````$$`5R=C8T:3)P,5]M,G`P7V$R<#%?9C)P
M,E]D,G`R7V,R<#!?>FEC<W(R<#!?>FEF96YC96DR<#!?>FUM=6PQ<#```"YS
M:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`
M+F1Y;G-Y;0`N9'EN<W1R`"YR96QA+F1Y;@`N<F5L82YP;'0`+G1E>'0`+G)O
M9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN
M:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`+G)I
M<V-V+F%T=')I8G5T97,`````````````````````````````````````````
M``````````````````````````````````````````````````````L````!
M`````@````````!P`@```````'`"````````&@````````````````````$`
M```````````````````3````!P````(`````````C`(```````",`@``````
M`"0````````````````````$````````````````````)@```/;__V\"````
M`````+`"````````L`(```````#@``````````0`````````"```````````
M`````````#`````+`````@````````"0`P```````)`#````````J`D`````
M```%`````@````@`````````&``````````X`````P````(`````````.`T`
M```````X#0```````'@$```````````````````!````````````````````
M0`````0````"`````````+`1````````L!$```````!8`@````````0`````
M````"``````````8`````````$H````$````0@`````````(%`````````@4
M````````0`4````````$````$`````@`````````&`````````!/`````0``
M``8`````````4!D```````!0&0```````*`#```````````````````0````
M`````!``````````5`````$````&`````````/`<````````\!P```````"6
M+0```````````````````@```````````````````%H````!`````@``````
M``"(2@```````(A*````````8$$```````````````````@`````````````
M``````!B`````0````(`````````Z(L```````#HBP```````/0`````````
M```````````$````````````````````<`````$````"`````````.",````
M````X(P```````"D!@``````````````````"````````````````````'H`
M```.`````P````````"XJP```````+B;````````"```````````````````
M``@`````````"`````````"&````#P````,`````````P*L```````#`FP``
M``````@````````````````````(``````````@`````````D@````8````#
M`````````,BK````````R)L```````#@`0````````4`````````"```````
M```0`````````)L````!`````P````````"HK0```````*B=````````6`(`
M``````````````````@`````````"`````````"@`````0````,`````````
M`+``````````H````````%`````````````````````(````````````````
M````I@````@````#`````````%"P````````4*````````!8````````````
M````````"````````````````````*L````!````,```````````````````
M`%"@````````,0````````````````````$``````````0````````"T````
M`P``<`````````````````````"!H````````%,````````````````````!
M`````````````````````0````,`````````````````````````U*``````
B``#&`````````````````````0``````````````````````
